@@ -8,6 +8,16 @@ noncomm = cotools.Paperset("data/noncomm_use_subset")
 data = cotools.Paperset("data/comm_use_subset")
 pprint(data[0])
 print(type(data[0]))
+
+# get the text for one feature
+cotools.text(data[0])
+
+cotools.texts(data[:15])
+
+data.text()
+
+data.apply(len)
+
 # dict
 
 pprint(data[:2])
